@@ -1,11 +1,14 @@
 """Main module, run me."""
 
 import sys
-from os import path
+from os import path, getcwd
 import imp
+import signal
 import curses
 import getopt
 
+sys.path.insert(0, getcwd())
+
 from gobject import MainLoop, io_add_watch, timeout_add, IO_IN
 from pysysmon import ui
 
@@ -54,6 +57,7 @@ def main():
 
     def inner(s):
         z = ui.UI(s, conf)
+        signal.signal(signal.SIGWINCH, lambda s, f: z.resize())
         for cb, timer in z.get_timers():
             timeout_add(timer * 1000, cb)
         for fp, cb in z.get_read_watches():
