@@ -1,9 +1,13 @@
 """Main UI."""
 
+import sys
 import math
 import curses
 from pysysmon.asynccb import AsynchroneousCallback
 from pysysmon.utils import any
+from termios import TIOCGWINSZ
+from struct import unpack
+from fcntl import ioctl
 
 # Why does math.{ceil,floor} not do this?
 ceil = lambda x: int(math.ceil(x))
@@ -23,6 +27,23 @@ def strip_ansi_codes(s):
 def attr_escape(s):
     return s.replace("%", "%%")
 
+def get_terminal_size():
+    """Returns terminal dimensions in a tuple (height, width).
+        
+    This function may return None on either height or width if
+    it is not known.
+    """
+
+    for f in sys.stdin, sys.stdout, sys.stderr:
+        d = None
+        try:
+            d = unpack("hh", ioctl(f.fileno(), TIOCGWINSZ, "    "))
+        except IOError:
+            pass
+    if not d:
+        d = (None, 80)
+    return d
+
 def _cb(self, cbs=()):
     all = bars = services = False
     for cb in cbs:
@@ -116,6 +137,15 @@ class UI(object):
     def get_bar_names(self):
         return (b.name for b in self.bars)
 
+    def resize(self, yx=None):
+        if not yx:
+            y, x = get_terminal_size()
+            if not y:
+                y = 25  # *shrug*
+            yx = y, x
+        curses.resizeterm(*yx)
+        self.recreate_windows()
+
     def recreate_windows(self):
         bar_lines = ceil(float(len(self.bars)) / self.conf.bars_per_line) + 1
         self.upper_height = upper_height = curses.LINES - bar_lines
